require 'business_insight_api_client/version'
require 'business_insight_api_client/helpers'
require 'business_insight_api_client/api'
require 'business_insight_api_client/client'
require 'business_insight_api_client/errors'
require 'business_insight_api_client/mash'
require 'oauth2'

# BusinessInsightApiClient configuration class
# This class allows to set a configuration uses in the whole application until reloaded.
module BusinessInsightApiClient

  class << self

    # @!attribute [rw] api_url
    # @return [String] the api url, default: https://api.nedap-bi.com
    attr_accessor :api_url

    # @!attribute [rw] authorization_url
    # @return [String] the authorization url of the api, default: https://nedap-bi.com
    attr_accessor :authorization_url

    # @!attribute [rw] default_content_type
    # @return [String] the default content, default: application/json
    attr_accessor :default_content_type

    # @attribute [rw] client_id
    # @return [String] [String] the client id uses in OAuth authorization
    attr_accessor :client_id

    # @attribute [rw] client_secret
    # @return [String] the client secret uses in OAuth authorization
    attr_accessor :client_secret

    # Configures the business insight api for usage.
    # This method expects an configuration block.
    # @example
    #   BusinessInsightApiClient.configure do |conf|
    #     conf.client_id = 'someclientid'
    #   end
    # @yield [configuration] the configuration class.
    # @yieldparam api_url [String]
    # @yieldparam authorization_url [String]
    # @yieldparam default_content_type [String]
    # @yieldparam client_id [String]
    # @yieldparam client_secret [String]
    # @return [Boolean, true]
    def configure
      yield self
      true
    end

  end
end

