module BusinessInsightApiClient
  module Api

    # Animal API based methods. This module contains methods to query the Animal API.
    module Animals

      # get: '/animals'
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def animals
        ::BusinessInsightApiClient::Mash.from_json client.get('/animals')
      end


      # get: '/animals/:id'
      # @param [Integer] animal_id animal id
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def animal(animal_id)
        ::BusinessInsightApiClient::Mash.from_json client.get("/animals/#{animal_id}")
      end

      # get: '/animals/with_life_number/:life_number'
      # @param [String] life_number animal life number
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def animal_with_life_number(life_number)
        body = { life_number: life_number }
        ::BusinessInsightApiClient::Mash.from_json client.get('/animals/with_life_number', body: body)
      end

      # get: '/animals/animal_with_responder/:responder'
      # @param [String] responder animal responder
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def animal_with_responder(responder)
        body = { responder: responder }
        ::BusinessInsightApiClient::Mash.from_json client.get('/animals/with_responder', body: body)
      end

      # get: '/animals/with_number/:number'
      # @param [Integer] number animal number
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def animal_with_number(number)
        body = { number: number }
        ::BusinessInsightApiClient::Mash.from_json client.get('/animals/with_number', body: body)
      end

      # post: '/animals/:animal'
      # @param [Hash] animal animal to be created. See docs for parameters.
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def create_animal(animal={})
        ::BusinessInsightApiClient::Mash.from_json client.post('/animals', animal.to_json)
      end

      # put: '/animals/:animal_id'
      # @param [Integer] animal_id animal to be updated.
      # @param [Hash] animal animal to be updated. See docs for parameters.
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def update_animal(animal_id, animal={})
        ::BusinessInsightApiClient::Mash.from_json client.put("/animals/#{animal_id}", animal.to_json)
      end

      # delete: '/animals/:animal_id'
      # @param [Integer] animal_id animal to be deleted.
      # @return [BusinessInsightApiClient::Mash] response mash.
      # @see https://api.nedap-bi.com/api/docs/
      def delete_animal(animal_id)
        ::BusinessInsightApiClient::Mash.from_json client.delete("/animals/#{animal_id}")
      end
    end
  end
end
