module BusinessInsightApiClient
  module Api

    # Groups API based methods. This module contains methods to query the Groups API.
    module Groups

      # get: '/groups'
      # @see https://api.nedap-bi.com/api/docs/
      def groups
        ::BusinessInsightApiClient::Mash.from_json client.get('/groups')
      end

      # get: '/groups/:id'
      # @param [Integer] id group id
      # @see https://api.nedap-bi.com/api/docs/
      def group(id)
        ::BusinessInsightApiClient::Mash.from_json client.get("/groups/#{id}")
      end

      # post: '/groups'
      # @param [Hash] group ({}) group to be created. See docs for parameters.
      # @see https://api.nedap-bi.com/api/docs/
      def create_group(group = {})
        ::BusinessInsightApiClient::Mash.from_json client.post('/groups', group.to_json)
      end

      # put: '/groups/:group_id'
      # @param [Integer] group_id group to be updated.
      # @param [Hash] group ({}) parameters to be updated. See docs for parameters.
      # @see https://api.nedap-bi.com/api/docs/
      def update_group(group_id, group = {})
        ::BusinessInsightApiClient::Mash.from_json client.put("/groups/#{group_id}", group.to_json)
      end
    end
  end
end
